@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2007 Hiroyuki Yamamoto and the Claws Mail team
+ * Copyright (C) 1999-2009 Hiroyuki Yamamoto and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -1519,6 +1519,16 @@ gchar *conv_unmime_header(const gchar *str, const gchar *default_encoding)
 				*destp++ = ' ';				\
 				left = MAX_LINELEN - 1;			\
 			}						\
+		} else if (destp == (guchar *)dest && left < 7) {	\
+			if (isspace(*(destp - 1)))			\
+				destp--;				\
+			else if (is_plain_text && isspace(*srcp))	\
+				srcp++;					\
+			if (*srcp) {					\
+				*destp++ = '\n';			\
+				*destp++ = ' ';				\
+				left = MAX_LINELEN - 1;			\
+			}						\
 		}							\
 	}								\
 }
@@ -1536,7 +1546,8 @@ void conv_encode_header_full(gchar *dest, gint len, const gchar *src,
 	guchar *destp = dest;
 	gboolean use_base64;
 
-	g_return_if_fail(g_utf8_validate(src, -1, NULL) == TRUE);
+	cm_return_if_fail(g_utf8_validate(src, -1, NULL) == TRUE);
+	cm_return_if_fail(destp != NULL);
 
 	if (MB_CUR_MAX > 1) {
 		use_base64 = TRUE;
