@@ -2,7 +2,7 @@
 
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2007 Hiroyuki Yamamoto and the Claws Mail team
+ * Copyright (C) 1999-2009 Hiroyuki Yamamoto and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -621,6 +621,8 @@ struct _FolderClass
 						 MsgInfo 	*msginfo,
 						 GSList		*tags_set,
 						 GSList		*tags_unset);
+	void		(*item_opened)		(FolderItem	*item);
+	void		(*item_closed)		(FolderItem	*item);
 };
 
 enum {
@@ -643,6 +645,11 @@ struct _FolderItem
 	gint total_msgs;
 	gint unreadmarked_msgs;
 	gint marked_msgs;
+	gint replied_msgs;
+	gint forwarded_msgs;
+	gint locked_msgs;
+	gint ignored_msgs;
+	gint watched_msgs;
 
 	gint order;
 
@@ -768,7 +775,9 @@ void   folder_func_to_all_folders	(FolderItemFunc function,
 					 gpointer data);
 void folder_count_total_msgs(guint *new_msgs, guint *unread_msgs, 
 			     guint *unreadmarked_msgs, guint *marked_msgs,
-			     guint *total_msgs);
+			     guint *total_msgs, guint *replied_msgs,
+			     guint *forwarded_msgs, guint *locked_msgs,
+			     guint *ignored_msgs, guint *watched_msgs);
 gchar *folder_get_status	(GPtrArray	*folders,
 				 gboolean	 full);
 
@@ -780,6 +789,9 @@ FolderItem *folder_find_item_from_real_path	(const gchar 	*path);
 FolderClass *folder_get_class_from_string	(const gchar 	*str);
 FolderItem *folder_find_child_item_by_name	(FolderItem	*item,
 						 const gchar	*name);
+/* return value is locale charset */
+gchar 	   *folder_get_identifier		(Folder *folder);
+/* return value is locale charset */
 gchar      *folder_item_get_identifier		(FolderItem	*item);
 FolderItem *folder_find_item_from_identifier	(const gchar	*identifier);
 gchar 	   *folder_item_get_name		(FolderItem 	*item);
@@ -847,8 +859,6 @@ void 	folder_item_change_msg_flags	(FolderItem 	*item,
 					 MsgPermFlags 	 newflags);
 gboolean folder_item_is_msg_changed	(FolderItem	*item,
 					 MsgInfo	*msginfo);
-/* return value is locale chaset */
-gchar * folder_item_get_identifier	(FolderItem * item);
 
 void folder_clean_cache_memory		(FolderItem *protected_item);
 void folder_clean_cache_memory_force	(void);
