@@ -1,6 +1,6 @@
 /*
  * Claws Mail -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 2003-2007 the Claws Mail team
+ * Copyright (C) 2003-2009 the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -291,7 +291,7 @@ void prefs_filtering_action_open(GSList *action_list,
 static void prefs_filtering_action_size_allocate_cb(GtkWidget *widget,
 					 GtkAllocation *allocation)
 {
-	g_return_if_fail(allocation != NULL);
+	cm_return_if_fail(allocation != NULL);
 
 	prefs_common.filteringactionwin_width = allocation->width;
 	prefs_common.filteringactionwin_height = allocation->height;
@@ -1263,7 +1263,7 @@ static void prefs_filtering_action_select_addressbook(void)
 
 static void prefs_filtering_action_enable_widget(GtkWidget* widget, const gboolean enable)
 {
-	g_return_if_fail(widget != NULL);
+	cm_return_if_fail(widget != NULL);
 
 	if(enable == TRUE)
 	{
