@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2007 Hiroyuki Yamamoto and the Claws Mail team
+ * Copyright (C) 1999-2009 Hiroyuki Yamamoto and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -61,7 +61,6 @@
 	}
 
 static void prefs_folder_item_register_page	(PrefsPage 	*page);
-static void prefs_folder_item_unregister_page	(PrefsPage 	*page);
 
 typedef struct _FolderItemGeneralPage FolderItemGeneralPage;
 typedef struct _FolderItemComposePage FolderItemComposePage;
@@ -628,13 +627,13 @@ static void general_save_folder_prefs(FolderItem *folder, FolderItemGeneralPage
 	if (folder->path == NULL)
 		return;
 
-	g_return_if_fail(prefs != NULL);
+	cm_return_if_fail(prefs != NULL);
 
 	if (page->item == folder) 
 		all = TRUE;
 
 	type = combobox_get_active_data(GTK_COMBO_BOX(page->folder_type));
-	if (all && folder->stype != type) {
+	if (all && folder->stype != type && page->item->parent_stype == F_NORMAL) {
 		folder_item_change_type(folder, type);
 	}
 
@@ -695,8 +694,8 @@ static gboolean general_save_recurse_func(GNode *node, gpointer data)
 	FolderItem *item = (FolderItem *) node->data;
 	FolderItemGeneralPage *page = (FolderItemGeneralPage *) data;
 
-	g_return_val_if_fail(item != NULL, TRUE);
-	g_return_val_if_fail(page != NULL, TRUE);
+	cm_return_val_if_fail(item != NULL, TRUE);
+	cm_return_val_if_fail(page != NULL, TRUE);
 
 	general_save_folder_prefs(item, page);
 
@@ -1069,7 +1068,7 @@ static void compose_save_folder_prefs(FolderItem *folder, FolderItemComposePage
 	if (page->item == folder) 
 		all = TRUE;
 
-	g_return_if_fail(prefs != NULL);
+	cm_return_if_fail(prefs != NULL);
 
 	if (item_protocol(folder) != A_NNTP) {
 		if (all || gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(page->request_return_receipt_rec_checkbtn))) {
@@ -1139,8 +1138,8 @@ static gboolean compose_save_recurse_func(GNode *node, gpointer data)
 	FolderItem *item = (FolderItem *) node->data;
 	FolderItemComposePage *page = (FolderItemComposePage *) data;
 
-	g_return_val_if_fail(item != NULL, TRUE);
-	g_return_val_if_fail(page != NULL, TRUE);
+	cm_return_val_if_fail(item != NULL, TRUE);
+	cm_return_val_if_fail(page != NULL, TRUE);
 
 	compose_save_folder_prefs(item, page);
 
@@ -1347,7 +1346,7 @@ static void templates_save_folder_prefs(FolderItem *folder, FolderItemTemplatesP
 	if (page->item == folder) 
 		all = TRUE;
 
-	g_return_if_fail(prefs != NULL);
+	cm_return_if_fail(prefs != NULL);
 
 	/* save and check formats */
 
@@ -1405,8 +1404,8 @@ static gboolean templates_save_recurse_func(GNode *node, gpointer data)
 	FolderItem *item = (FolderItem *) node->data;
 	FolderItemTemplatesPage *page = (FolderItemTemplatesPage *) data;
 
-	g_return_val_if_fail(item != NULL, TRUE);
-	g_return_val_if_fail(page != NULL, TRUE);
+	cm_return_val_if_fail(item != NULL, TRUE);
+	cm_return_val_if_fail(page != NULL, TRUE);
 
 	templates_save_folder_prefs(item, page);
 
@@ -1677,8 +1676,3 @@ static void prefs_folder_item_register_page(PrefsPage *page)
 {
 	prefs_pages = g_slist_append(prefs_pages, page);
 }
-
-static void prefs_folder_item_unregister_page(PrefsPage *page)
-{
-	prefs_pages = g_slist_remove(prefs_pages, page);
-}
