@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2007 Hiroyuki Yamamoto & The Claws Mail Team
+ * Copyright (C) 1999-2009 Hiroyuki Yamamoto & The Claws Mail Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -156,8 +156,8 @@ void procmime_mimeinfo_free_all(MimeInfo *mimeinfo)
 
 MimeInfo *procmime_mimeinfo_parent(MimeInfo *mimeinfo)
 {
-	g_return_val_if_fail(mimeinfo != NULL, NULL);
-	g_return_val_if_fail(mimeinfo->node != NULL, NULL);
+	cm_return_val_if_fail(mimeinfo != NULL, NULL);
+	cm_return_val_if_fail(mimeinfo->node != NULL, NULL);
 
 	if (mimeinfo->node->parent == NULL)
 		return NULL;
@@ -166,8 +166,8 @@ MimeInfo *procmime_mimeinfo_parent(MimeInfo *mimeinfo)
 
 MimeInfo *procmime_mimeinfo_next(MimeInfo *mimeinfo)
 {
-	g_return_val_if_fail(mimeinfo != NULL, NULL);
-	g_return_val_if_fail(mimeinfo->node != NULL, NULL);
+	cm_return_val_if_fail(mimeinfo != NULL, NULL);
+	cm_return_val_if_fail(mimeinfo->node != NULL, NULL);
 
 	if (mimeinfo->node->children)
 		return (MimeInfo *) mimeinfo->node->children->data;
@@ -242,8 +242,8 @@ const gchar *procmime_mimeinfo_get_parameter(MimeInfo *mimeinfo, const gchar *na
 {
 	const gchar *value;
 
-	g_return_val_if_fail(mimeinfo != NULL, NULL);
-	g_return_val_if_fail(name != NULL, NULL);
+	cm_return_val_if_fail(mimeinfo != NULL, NULL);
+	cm_return_val_if_fail(name != NULL, NULL);
 
 	value = g_hash_table_lookup(mimeinfo->dispositionparameters, name);
 	if (value == NULL)
@@ -291,7 +291,7 @@ gboolean procmime_decode_content(MimeInfo *mimeinfo)
 	gchar lastline[BUFFSIZE];
 	memset(lastline, 0, BUFFSIZE);
 		   
-	g_return_val_if_fail(mimeinfo != NULL, FALSE);
+	cm_return_val_if_fail(mimeinfo != NULL, FALSE);
 
 	if (prefs_common.respect_flowed_format &&
 	    mimeinfo->type == MIMETYPE_TEXT && 
@@ -476,15 +476,18 @@ gboolean procmime_encode_content(MimeInfo *mimeinfo, EncodingType encoding)
 		return FALSE;
 	}
 
-	if (mimeinfo->content == MIMECONTENT_FILE) {
+	if (mimeinfo->content == MIMECONTENT_FILE && mimeinfo->data.filename) {
 		if ((infp = g_fopen(mimeinfo->data.filename, "rb")) == NULL) {
 			g_warning("Can't open file %s\n", mimeinfo->data.filename);
+			fclose(outfp);
 			return FALSE;
 		}
 	} else if (mimeinfo->content == MIMECONTENT_MEM) {
 		infp = str_open_as_stream(mimeinfo->data.mem);
-		if (infp == NULL)
+		if (infp == NULL) {
+			fclose(outfp);
 			return FALSE;
+		}
 	}
 
 	if (encoding == ENC_BASE64) {
@@ -499,6 +502,7 @@ gboolean procmime_encode_content(MimeInfo *mimeinfo, EncodingType encoding)
 				if (canonicalize_file(mimeinfo->data.filename, tmp_file) < 0) {
 					g_free(tmp_file);
 					fclose(infp);
+					fclose(outfp);
 					return FALSE;
 				}
 				if ((tmp_fp = g_fopen(tmp_file, "rb")) == NULL) {
@@ -506,6 +510,7 @@ gboolean procmime_encode_content(MimeInfo *mimeinfo, EncodingType encoding)
 					claws_unlink(tmp_file);
 					g_free(tmp_file);
 					fclose(infp);
+					fclose(outfp);
 					return FALSE;
 				}
 			} else {
@@ -514,8 +519,10 @@ gboolean procmime_encode_content(MimeInfo *mimeinfo, EncodingType encoding)
 				infp = str_open_as_stream(out);
 				tmp_fp = infp;
 				g_free(out);
-				if (infp == NULL)
+				if (infp == NULL) {
+					fclose(outfp);
 					return FALSE;
+				}
 			}
 		}
 
@@ -604,8 +611,8 @@ gint procmime_get_part(const gchar *outfile, MimeInfo *mimeinfo)
 	gint restlength, readlength;
 	gint saved_errno = 0;
 
-	g_return_val_if_fail(outfile != NULL, -1);
-	g_return_val_if_fail(mimeinfo != NULL, -1);
+	cm_return_val_if_fail(outfile != NULL, -1);
+	cm_return_val_if_fail(mimeinfo != NULL, -1);
 
 	if (mimeinfo->encoding_type != ENC_BINARY && !procmime_decode_content(mimeinfo))
 		return -EINVAL;
@@ -660,7 +667,7 @@ static FILE *procmime_get_text_content(MimeInfo *mimeinfo)
 	gchar *tmpfile;
 	gboolean err = FALSE;
 
-	g_return_val_if_fail(mimeinfo != NULL, NULL);
+	cm_return_val_if_fail(mimeinfo != NULL, NULL);
 
 	if (!procmime_decode_content(mimeinfo))
 		return NULL;
@@ -757,7 +764,7 @@ FILE *procmime_get_first_text_content(MsgInfo *msginfo)
 	MimeInfo *mimeinfo, *partinfo;
 	gboolean empty_ok = FALSE, short_scan = TRUE;
 	START_TIMING("");
-	g_return_val_if_fail(msginfo != NULL, NULL);
+	cm_return_val_if_fail(msginfo != NULL, NULL);
 
 	/* first we try to short-scan (for speed), refusing empty parts */
 scan_again:
@@ -825,7 +832,7 @@ FILE *procmime_get_first_encrypted_text_content(MsgInfo *msginfo)
 	FILE *outfp = NULL;
 	MimeInfo *mimeinfo, *partinfo, *encinfo;
 
-	g_return_val_if_fail(msginfo != NULL, NULL);
+	cm_return_val_if_fail(msginfo != NULL, NULL);
 
 	mimeinfo = procmime_scan_message(msginfo);
 	if (!mimeinfo) {
@@ -861,7 +868,7 @@ gboolean procmime_msginfo_is_encrypted(MsgInfo *msginfo)
 	MimeInfo *mimeinfo, *partinfo;
 	gboolean result = FALSE;
 
-	g_return_val_if_fail(msginfo != NULL, FALSE);
+	cm_return_val_if_fail(msginfo != NULL, FALSE);
 
 	mimeinfo = procmime_scan_message(msginfo);
 	if (!mimeinfo) {
@@ -881,10 +888,10 @@ static gboolean procmime_find_string_part(MimeInfo *mimeinfo, const gchar *filen
 	FILE *outfp;
 	gchar buf[BUFFSIZE];
 
-	g_return_val_if_fail(mimeinfo != NULL, FALSE);
-	g_return_val_if_fail(mimeinfo->type == MIMETYPE_TEXT, FALSE);
-	g_return_val_if_fail(str != NULL, FALSE);
-	g_return_val_if_fail(find_func != NULL, FALSE);
+	cm_return_val_if_fail(mimeinfo != NULL, FALSE);
+	cm_return_val_if_fail(mimeinfo->type == MIMETYPE_TEXT, FALSE);
+	cm_return_val_if_fail(str != NULL, FALSE);
+	cm_return_val_if_fail(find_func != NULL, FALSE);
 
 	outfp = procmime_get_text_content(mimeinfo);
 
@@ -912,9 +919,9 @@ gboolean procmime_find_string(MsgInfo *msginfo, const gchar *str,
 	gchar *filename;
 	gboolean found = FALSE;
 
-	g_return_val_if_fail(msginfo != NULL, FALSE);
-	g_return_val_if_fail(str != NULL, FALSE);
-	g_return_val_if_fail(find_func != NULL, FALSE);
+	cm_return_val_if_fail(msginfo != NULL, FALSE);
+	cm_return_val_if_fail(str != NULL, FALSE);
+	cm_return_val_if_fail(find_func != NULL, FALSE);
 
 	filename = procmsg_get_message_file(msginfo);
 	if (!filename) return FALSE;
@@ -944,7 +951,7 @@ gchar *procmime_get_tmp_file_name(MimeInfo *mimeinfo)
 	gchar *filename;
 	gchar f_prefix[10];
 
-	g_return_val_if_fail(mimeinfo != NULL, NULL);
+	cm_return_val_if_fail(mimeinfo != NULL, NULL);
 
 	g_snprintf(f_prefix, sizeof(f_prefix), "%08x.", id++);
 
@@ -1625,8 +1632,8 @@ static void parse_parameters(const gchar *parameters, GHashTable *table)
 		down_attr = g_utf8_strdown(attribute, -1);
 		orig_down_attr = down_attr;
 	
-		len = strlen(down_attr);
-		if (down_attr[len - 1] == '*') {
+		len = down_attr ? strlen(down_attr):0;
+		if (len > 0 && down_attr[len - 1] == '*') {
 			gchar *srcpos, *dstpos, *endpos;
 
 			convert = TRUE;
@@ -1670,7 +1677,7 @@ static void parse_parameters(const gchar *parameters, GHashTable *table)
 			while (value[strlen(value)-1] == ' ') 
 				value[strlen(value)-1] = '\0';
 		}		
-		if (strrchr(down_attr, '*') != NULL) {
+		if (down_attr && strrchr(down_attr, '*') != NULL) {
 			gchar *tmpattr;
 
 			tmpattr = g_strdup(down_attr);
@@ -1757,8 +1764,8 @@ static void parse_parameters(const gchar *parameters, GHashTable *table)
 
 static void procmime_parse_content_type(const gchar *content_type, MimeInfo *mimeinfo)
 {
-	g_return_if_fail(content_type != NULL);
-	g_return_if_fail(mimeinfo != NULL);
+	cm_return_if_fail(content_type != NULL);
+	cm_return_if_fail(mimeinfo != NULL);
 
 	/* RFC 2045, page 13 says that the mime subtype is MANDATORY;
 	 * if it's not available we use the default Content-Type */
@@ -1798,8 +1805,8 @@ static void procmime_parse_content_disposition(const gchar *content_disposition,
 {
 	gchar *tmp, *params;
 
-	g_return_if_fail(content_disposition != NULL);
-	g_return_if_fail(mimeinfo != NULL);
+	cm_return_if_fail(content_disposition != NULL);
+	cm_return_if_fail(mimeinfo != NULL);
 
 	tmp = g_strdup(content_disposition);
 	if ((params = strchr(tmp, ';')) != NULL) {
@@ -1863,7 +1870,7 @@ void procmime_mimeparser_unregister(MimeParser *parser)
 
 static gboolean procmime_mimeparser_parse(MimeParser *parser, MimeInfo *mimeinfo)
 {
-	g_return_val_if_fail(parser->parse != NULL, FALSE);
+	cm_return_val_if_fail(parser->parse != NULL, FALSE);
 	return parser->parse(parser, mimeinfo);	
 }
 
@@ -2042,7 +2049,7 @@ static MimeInfo *procmime_scan_file_full(const gchar *filename, gboolean short_s
 {
 	MimeInfo *mimeinfo;
 
-	g_return_val_if_fail(filename != NULL, NULL);
+	cm_return_val_if_fail(filename != NULL, NULL);
 
 	mimeinfo = procmime_scan_file_with_offset(filename, 0, short_scan);
 
@@ -2066,7 +2073,7 @@ static MimeInfo *procmime_scan_queue_file_full(const gchar *filename, gboolean s
 	gchar buf[BUFFSIZE];
 	gint offset = 0;
 
-	g_return_val_if_fail(filename != NULL, NULL);
+	cm_return_val_if_fail(filename != NULL, NULL);
 
 	/* Open file */
 	if ((fp = g_fopen(filename, "rb")) == NULL)
@@ -2175,6 +2182,7 @@ static void write_parameters(gpointer key, gpointer value, gpointer user_data)
 		g_string_append_printf(buf, "%s=\"%s\"", param, val);
 		break;
 
+#if 0 /* we don't use that for now */
 	case ENC_AS_EXTENDED:
 		if (!g_utf8_validate(val, -1, NULL))
 			g_string_append_printf(buf, "%s*=%s''", param,
@@ -2192,7 +2200,7 @@ static void write_parameters(gpointer key, gpointer value, gpointer user_data)
 			}
 		}
 		break;		
-
+#endif
 	case ENC_AS_ENCWORD:
 		len = MAX(strlen(val)*6, 512);
 		tmp = g_malloc(len+1);
